@@ -21,10 +21,10 @@ from docuploader import log
 def run(
     args: List,
     *,
-    cwd: str = None,
     check: bool = True,
     hide_output: bool = True,
-    timeout: int = None,
+    timeout: Optional[int] = None,
+    cwd: Optional[str] = None,
 ) -> subprocess.CompletedProcess:
     if hide_output:
         stdout: Optional[int] = subprocess.PIPE
